assign_subject2plate: assign subject to a plate for longitudinal randomization

View source: R/olink_plate_randomizer.R

assign_subject2plateR Documentation

assign subject to a plate for longitudinal randomization

Description

assign subject to a plate for longitudinal randomization

Usage

assign_subject2plate(plate_map, manifest, subject_id)

Arguments

plate_map

character vector of locations available for samples including plate, row and columns

manifest

sample manifest mapping sample IDs and subject IDs

subject_id

id of subject

Value

plate_map adding sample IDs to plates keeping samples from the same subject on the same plate


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.