check_checksum: Help function comparing the checksum reported by Olink...

View source: R/read_npx_zip.R

check_checksumR Documentation

Help function comparing the checksum reported by Olink software to the checksum of the Olink data file from the input zip-compressed file.

Description

Runs only if one of "MD5_checksum.txt" or "checksum_sha256.txt". are present in the input zip-compressed file. This function does not check if the checksum_file is in acceptable format.

Usage

check_checksum(checksum_file, npx_file)

Arguments

checksum_file

Extracted checksum file from the zip-compressed file that contains the checksum file from Olink software.

npx_file

Extracted file from the zip-compressed file that contains the Olink data file from Olink software.

Value

NULL or an error if the files could not be opened or if checksum did not match.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.