check_darid: Help function checking for DARID and PanelDataArchiveVersion...

View source: R/check_npx.R

check_daridR Documentation

Help function checking for DARID and PanelDataArchiveVersion combinations

Description

DarIDs D.07, 08, 10, and 14 need to exported with Panel Data Archive Version 1.5 or later. This function identifies cases where DataAnalysisRefID are paired with earlier PanelDataArchiveVersion.

Usage

check_darid(df, col_names)

Arguments

df

A "tibble" or "ArrowObject" from read_npx.

Value

A warning message if any invalid combinations are found.

Author(s)

Kathleen Nevola Kang Dong Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.