check_file_exists: Help function checking if file exists.

View source: R/check_file.R

check_file_existsR Documentation

Help function checking if file exists.

Description

Check one file at a time if it exists.

Usage

check_file_exists(file, error = FALSE)

Arguments

file

Path to Olink software output file in wide or long format. Expecting extensions "xls" or "xlsx" for excel files, "csv" or "txt" for delim files, "parquet" for parquet files, and "zip" for compressed files.

error

Scalar boolean to return an error instead of a FALSE (default = FALSE).

Value

TRUE if the file exists, and FALSE if not; error if the file does not exist and error = TRUE.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.