check_file_extension: Help function checking if file extension is acceptable.

View source: R/check_file.R

check_file_extensionR Documentation

Help function checking if file extension is acceptable.

Description

Use variable accepted_npx_file_ext to check if extension of the input file is acceptable. Expecting one of ""xls" or "xlsx" for excel files, "csv" or "txt" for delim files, "parquet" for parquet files, and "zip" for compressed files".

Usage

check_file_extension(file)

Arguments

file

Path to Olink software output file in wide or long format. Expecting extensions "xls" or "xlsx" for excel files, "csv" or "txt" for delim files, "parquet" for parquet files, and "zip" for compressed files.

Value

The type of the file extension based on the global variable accepted_npx_file_ext.


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.