check_is_arrow_object: Help function checking if a variable is an R6 ArrowObject.

View source: R/check_df.R

check_is_arrow_objectR Documentation

Help function checking if a variable is an R6 ArrowObject.

Description

Help function checking if a variable is an R6 ArrowObject.

Usage

check_is_arrow_object(x, error = FALSE)

Arguments

x

Variable to check.

error

Scalar boolean to return an error instead of a FALSE (default = FALSE).

Value

Boolean, TRUE or FALSE, if the variable is of the correct class; If output is FALSE and error = TRUE, an error is thrown.

Author(s)

Klev Diamanti

See Also

check_is_character check_is_integer check_is_numeric check_is_boolean check_is_scalar_character check_is_scalar_integer check_is_scalar_numeric check_is_scalar_boolean check_is_tibble check_is_dataset check_is_arrow_object check_is_list


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.