check_library_installed: Help function to check if suggested libraries are installed...

View source: R/check_library_installed.R

check_library_installedR Documentation

Help function to check if suggested libraries are installed when required.

Description

Help function to check if suggested libraries are installed when required.

Usage

check_library_installed(x, error = FALSE)

Arguments

x

A character vector of R libraries.

error

Boolean to return error or a boolean (default).

Value

Boolean if the library is installed or not, and an error if error = TRUE.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.