check_log_colname: Check if check_log has identified required column in the...

View source: R/check_columns.R

check_log_colnameR Documentation

Check if check_log has identified required column in the dataset.

Description

Check if check_log has identified required column in the dataset.

Usage

check_log_colname(check_log, col_key)

Arguments

check_log

A named list returned by check_npx(). If NULL, check_npx() will be run internally using df.

col_key

Column key for which to retrieve alternative column names. One of "sample_id", "sample_type", "assay_type", "olink_id", "uniprot", "assay", "panel", "block", "plate_id", "panel_version", "lod", "quant", "ext_npx", "count", "qc_warning", "assay_warn", "normalization", and "qc_version".

Value

Nothing or an error message if the required column is missing.


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.