check_npx_all_na_assays: Help function to identify Olink assays with all quantified...

View source: R/check_npx.R

check_npx_all_na_assaysR Documentation

Help function to identify Olink assays with all quantified values NA

Description

This function checks if there are assays with the quantified values for all samples NA.

Usage

check_npx_all_na_assays(df, col_names)

Arguments

df

A "tibble" or "ArrowObject" from read_npx.

col_names

A list of matched column names. This is the output of the check_npx_col_names function.

Details

We have added the tags importFrom for "dbplyr" and "duckdb" because "devtools::check()" would complain with a note that the two libraries are imported but never used. To avoid that we used solutions taken from here:

  1. https://github.com/hadley/r-pkgs/issues/203

  2. https://github.com/pbs-software/pbs-modelling/issues/95

Value

A character vector containing OlinkID of assays with quantified values NA for all samples, otherwise returns character(0).

Author(s)

Simon Forsberg Masoumeh Sheikhi


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.