check_npx_col_class: Help function checking types of columns in data.

View source: R/check_npx.R

check_npx_col_classR Documentation

Help function checking types of columns in data.

Description

This function checks if certain columns from df have the correct type to enable downstream analysis. Columns to be checked are marked as such in the columns col_class and col_class_check of column_name_dict.

Usage

check_npx_col_class(df, col_names)

Arguments

df

A "tibble" or "ArrowObject" from read_npx.

col_names

A list of matched column names. This is the output of the check_npx_col_names function.

Value

A data frame with the columns col_name, col_key, col_class and expected_col_class marking columns with the incorrect type.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.