check_npx_duplicate_sample_ids: Help function checking for duplicate sample identifiers in...

View source: R/check_npx.R

check_npx_duplicate_sample_idsR Documentation

Help function checking for duplicate sample identifiers in data.

Description

This function checks if there are duplicate sample identifiers for any assay.

Usage

check_npx_duplicate_sample_ids(df, col_names)

Arguments

df

A "tibble" or "ArrowObject" from read_npx.

col_names

A list of matched column names. This is the output of the check_npx_col_names function.

Value

A character vector of duplicate SampleID found in the data.

Author(s)

Masoumeh Sheikhi


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.