check_npx_nonunique_uniprot: Help function checking for assays mapping to multiple UniProt...

View source: R/check_npx.R

check_npx_nonunique_uniprotR Documentation

Help function checking for assays mapping to multiple UniProt identifiers.

Description

Occasionally, updates in panel versions include updates in UniProt identifiers (e.g. change in formatting). This function identifies cases where an assay identifier OlinkID maps to multiple UniProt identifiers.

Usage

check_npx_nonunique_uniprot(df, col_names)

Arguments

df

A "tibble" or "ArrowObject" from read_npx.

col_names

A list of matched column names. This is the output of the check_npx_col_names function.

Value

A character vector of assay identifiers OlinkID that map to more than one UniProt identifiers.

Author(s)

Kathleen Nevola Kang Dong Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.