check_npx_update_col_names: Update column names to be used in downstream analyses

View source: R/check_npx.R

check_npx_update_col_namesR Documentation

Update column names to be used in downstream analyses

Description

OlinkAnalyze uses pre-defined names of columns of data frames to perform downstream analyses. However, in certain cases the columns of interest might be named differently. The aim of this function is to assign custom-named columns of a data frame to internally expected variables that will in turn enable analysis of Olink data. For example, if one wished to #' use the column PCNormalizedNPX for their analysis instead of the column NPX, then they can assign this new name to the internal variable quant to inform the package that in the downstream analysis PCNormalizedNPX should be used.

This function takes as input a named character vector with internal column names as names and column names of the current data set as values. Names of the input vector can be one or more of the following: sample_id, sample_type, assay_type, olink_id, uniprot, assay, panel, block, plate_id, panel_version, lod, quant, ext_npx, count, qc_warning, assay_warn, normalization, and qc_version

Usage

check_npx_update_col_names(preferred_names)

Arguments

preferred_names

A named character vector where names are internal column names and values are column names to be selected from the input data frame. Read the description for further information.

Value

column_name_dict updated based on preferred_names.

Author(s)

Klev Diamanti Masoumeh Sheikhi


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.