check_olink_broader_platform: Help function checking that broad_platform is expected.

View source: R/get_olink_platforms.R

check_olink_broader_platformR Documentation

Description

Help function checking that broad_platform is expected.

Usage

check_olink_broader_platform(
  x,
  platform_name = NULL,
  data_type = NULL,
  quant_type = NULL
)

Arguments

x

Name of the broader Olink platform. One of "NGS" and "qPCR".

platform_name

Name of the platform_name to filter for. If NULL all platforms are considered, otherwise one of "Explore 3072", "Explore HT", "Flex", "Focus", "Reveal", "Target 48", and "Target 96" is expected.

data_type

Name of the data_type to filter the Olink for. If NULL all data types are considered, otherwise one of "Ct", "NPX", and "Quantified" is expected.

quant_type

Name of the quant_type to filter for. If NULL all quantification types are considered, otherwise one of "absolute" and "relative" is expected.

Value

NULL if broader Olink platform is expected, otherwise an error.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.