check_olink_platform: Help function checking that olink_platform is expected.

View source: R/get_olink_platforms.R

check_olink_platformR Documentation

Description

Help function checking that olink_platform is expected.

Usage

check_olink_platform(
  x,
  broad_platform = NULL,
  data_type = NULL,
  quant_type = NULL
)

Arguments

x

Name of Olink platform. One of "Explore 3072", "Explore HT", "Flex", "Focus", "Reveal", "Target 48", and "Target 96".

broad_platform

Name of the broad_platform to filter for. If NULL all broader platforms are considered, otherwise one of "NGS" and "qPCR" is expected.

data_type

Name of the data_type to filter the Olink for. If NULL all data types are considered, otherwise one of "Ct", "NPX", and "Quantified" is expected.

quant_type

Name of the quant_type to filter for. If NULL all quantification types are considered, otherwise one of "absolute" and "relative" is expected.

Value

NULL if platform is expected, otherwise an error.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.