check_olink_quant_type: Help function checking that data_type is expected.

View source: R/get_olink_platforms.R

check_olink_quant_typeR Documentation

Description

Help function checking that data_type is expected.

Usage

check_olink_quant_type(
  x,
  broad_platform = NULL,
  platform_name = NULL,
  data_type = NULL
)

Arguments

x

The name of the Olink quantification type. One of "absolute" and "relative".

broad_platform

Name of the broad_platform to filter for. If NULL all broader platforms are considered, otherwise one of "NGS" and "qPCR" is expected.

platform_name

Name of the platform_name to filter for. If NULL all platforms are considered, otherwise one of "Explore 3072", "Explore HT", "Flex", "Focus", "Reveal", "Target 48", and "Target 96" is expected.

data_type

Name of the data_type to filter the Olink for. If NULL all data types are considered, otherwise one of "Ct", "NPX", and "Quantified" is expected.

Value

NULL if quantification type is expected, otherwise an error.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.