check_out_df_arg: Help function checking that the requested output class of the...

View source: R/read_npx_utils.R

check_out_df_argR Documentation

Help function checking that the requested output class of the read_npx* functions is acceptable.

Description

Help function checking that the requested output class of the read_npx* functions is acceptable.

Usage

check_out_df_arg(out_df)

Arguments

out_df

The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble".

Value

Error if out_df is not one of "tibble" and "arrow".

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.