dot-check_params: Common parameters for check functions.

.check_paramsR Documentation

Common parameters for check functions.

Description

Common parameters for check functions.

Usage

.check_params(x, error)

Arguments

x

Variable to check.

error

Scalar boolean to return an error instead of a FALSE (default = FALSE).

Value

Boolean, TRUE or FALSE, if the variable is of the correct class; If output is FALSE and error = TRUE, an error is thrown.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on Sept. 18, 2026, 5:06 p.m.