dot-get_olink_data_details: Common parameters for getter functions in this file.

.get_olink_data_detailsR Documentation

Description

Common parameters for getter functions in this file.

Usage

.get_olink_data_details(broad_platform, platform_name, data_type, quant_type)

Arguments

broad_platform

Name of the broad_platform to filter for. If NULL all broader platforms are considered, otherwise one of "NGS" and "qPCR" is expected.

platform_name

Name of the platform_name to filter for. If NULL all platforms are considered, otherwise one of "Explore 3072", "Explore HT", "Flex", "Focus", "Reveal", "Target 48", and "Target 96" is expected.

data_type

Name of the data_type to filter the Olink for. If NULL all data types are considered, otherwise one of "Ct", "NPX", and "Quantified" is expected.

quant_type

Name of the quant_type to filter for. If NULL all quantification types are considered, otherwise one of "absolute" and "relative" is expected.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.