extract_check_log: Retrieve the check log from an Olink data object

View source: R/olink_class.R

extract_check_logR Documentation

Retrieve the check log from an Olink data object

Description

Extracts the check log from an olink_class tibble or an ArrowObject with embedded metadata. Returns NULL if no check log is found.

Usage

extract_check_log(df)

Arguments

df

A data object, typically from read_npx(), clean_npx() or olink_normalization().

Value

A named list (the check log) or NULL if no check log is attached.

Examples

## Not run: 
# read and check data
  npx_file <- system.file(
    "extdata",
    "npx_data_ext.parquet",
    package = "OlinkAnalyze"
  )

  npx_df <- OlinkAnalyze::read_npx(
    filename = npx_file
  )

  check_log <- OlinkAnalyze::check_npx(
    df = npx_df
  )

  # attach check_log to the data
  npx_obj <- OlinkAnalyze::new_olink_class(
    df = npx_df,
    check_log = check_log
  )

  # retrieve check_log
  OlinkAnalyze::extract_check_log(
    df = npx_obj
  )

## End(Not run)


OlinkAnalyze documentation built on Sept. 18, 2026, 5:06 p.m.