get_alt_colnames: Gets alternative column names for a given column key.

View source: R/get_others.R

get_alt_colnamesR Documentation

Gets alternative column names for a given column key.

Description

Gets alternative column names for a given column key.

Usage

get_alt_colnames(col_key)

Arguments

col_key

Column key for which to retrieve alternative column names. One of "sample_id", "sample_type", "assay_type", "olink_id", "uniprot", "assay", "panel", "block", "plate_id", "panel_version", "lod", "quant", "ext_npx", "count", "qc_warning", "assay_warn", "normalization", and "qc_version".

Value

A character vector of alternative column names corresponding to the provided column key.

Examples


  OlinkAnalyze:::get_alt_colnames(col_key = "sample_id")


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.