get_checksum_file: Help function to get the file name of the checksum file from...

View source: R/read_npx_zip.R

get_checksum_fileR Documentation

Help function to get the file name of the checksum file from the list of contents of a zip-compressed file.

Description

Help function to get the file name of the checksum file from the list of contents of a zip-compressed file.

Usage

get_checksum_file(files)

Arguments

files

A character vector listing file names included in the zip-compressed input file.

Value

The file name of the checksum file, or NA if file is absent.

Author(s)

Klev Diamanti

See Also

read_npx_zip get_npx_file check_checksum


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.