get_field_separator: Help function to get the separator of a delimited file...

View source: R/read_npx_delim.R

get_field_separatorR Documentation

Help function to get the separator of a delimited file exported from Olink software.

Description

This function uses the first line of the provided file to determine the separator of the file.

Note: The function does not allow presence of commas and semicolons on the same line.

Usage

get_field_separator(file)

Arguments

file

Path to Olink software output delimited file in wide or long format. Expecting file extensions "csv" or "txt".

Value

The file delimiter ";", ",", " ", "|", or ":".

Author(s)

Klev Diamanti

See Also

read_npx_delim


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.