get_file_ext: Gets all file extensions based on the file format.

View source: R/get_others.R

get_file_extR Documentation

Gets all file extensions based on the file format.

Description

Gets all file extensions based on the file format.

Usage

get_file_ext(name_sub = NULL)

Arguments

name_sub

Substring of file format. One of "excel", "delim", "parquet", "compressed", and "NULL". If NULL all file extensions are returned.

Value

Character vector with accepted file extensions.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.