get_npx_file: Help function to get the file name of the Olink data file...

View source: R/read_npx_zip.R

get_npx_fileR Documentation

Help function to get the file name of the Olink data file from the list of contents of a zip-compressed file.

Description

Help function to get the file name of the Olink data file from the list of contents of a zip-compressed file.

Usage

get_npx_file(files, excl_file_ext = c("zip"))

Arguments

files

A character vector listing file names included in the zip-compressed input file.

excl_file_ext

Character vector of file extensions that should not be considered as Olink data file. Mainly used to avoid nested compressed files.

Value

The file name of the Olink data file.

Author(s)

Klev Diamanti

See Also

read_npx_zip get_checksum_file check_checksum


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.