get_olink_broader_platforms: Get names of selected broader Olink platforms.

View source: R/get_olink_platforms.R

get_olink_broader_platformsR Documentation

Description

Get names of selected broader Olink platforms.

Usage

get_olink_broader_platforms(
  platform_name = NULL,
  data_type = NULL,
  quant_type = NULL
)

Arguments

platform_name

Name of the platform_name to filter for. If NULL all platforms are considered, otherwise one of "Explore 3072", "Explore HT", "Flex", "Focus", "Reveal", "Target 48", and "Target 96" is expected.

data_type

Name of the data_type to filter the Olink for. If NULL all data types are considered, otherwise one of "Ct", "NPX", and "Quantified" is expected.

quant_type

Name of the quant_type to filter for. If NULL all quantification types are considered, otherwise one of "absolute" and "relative" is expected.

Value

A character vector with names of Olink broader platforms filtered by platform_name, data_type, and quant_type.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.