get_olink_data_types: Get names of selected Olink quantification methods (data...

View source: R/get_olink_platforms.R

get_olink_data_typesR Documentation

Description

Get names of selected Olink quantification methods (data types).

Usage

get_olink_data_types(
  broad_platform = NULL,
  platform_name = NULL,
  quant_type = NULL
)

Arguments

broad_platform

Name of the broad_platform to filter for. If NULL all broader platforms are considered, otherwise one of "NGS" and "qPCR" is expected.

platform_name

Name of the platform_name to filter for. If NULL all platforms are considered, otherwise one of "Explore 3072", "Explore HT", "Flex", "Focus", "Reveal", "Target 48", and "Target 96" is expected.

quant_type

Name of the quant_type to filter for. If NULL all quantification types are considered, otherwise one of "absolute" and "relative" is expected.

Value

A character vector with names of Olink quantification methods (data types) filtered by broad_platform, platform_name, and quant_type.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.