get_olink_platforms: Get names of selected Olink platforms.

View source: R/get_olink_platforms.R

get_olink_platformsR Documentation

Description

Get names of selected Olink platforms.

Usage

get_olink_platforms(broad_platform = NULL, data_type = NULL, quant_type = NULL)

Arguments

broad_platform

Name of the broad_platform to filter for. If NULL all broader platforms are considered, otherwise one of "NGS" and "qPCR" is expected.

data_type

Name of the data_type to filter the Olink for. If NULL all data types are considered, otherwise one of "Ct", "NPX", and "Quantified" is expected.

quant_type

Name of the quant_type to filter for. If NULL all quantification types are considered, otherwise one of "absolute" and "relative" is expected.

Value

A character vector with names of Olink platforms filtered by broad_platform, data_type, and quant_type.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.