get_olink_quant_types: Get names of selected Olink quantification types.

View source: R/get_olink_platforms.R

get_olink_quant_typesR Documentation

Description

Get names of selected Olink quantification types.

Usage

get_olink_quant_types(
  broad_platform = NULL,
  platform_name = NULL,
  data_type = NULL
)

Arguments

broad_platform

Name of the broad_platform to filter for. If NULL all broader platforms are considered, otherwise one of "NGS" and "qPCR" is expected.

platform_name

Name of the platform_name to filter for. If NULL all platforms are considered, otherwise one of "Explore 3072", "Explore HT", "Flex", "Focus", "Reveal", "Target 48", and "Target 96" is expected.

data_type

Name of the data_type to filter the Olink for. If NULL all data types are considered, otherwise one of "Ct", "NPX", and "Quantified" is expected.

Value

A character vector with names of Olink quantification types filtered by broad_platform, platform_name, and data_type.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.