olink_display_plate_dist: Plot distributions of a given variable for all plates

View source: R/olink_plate_randomizer.R

olink_display_plate_distR Documentation

Description

Displays a bar chart for each plate representing the distribution of the given grouping variable on each plate using ggplot2::ggplot and ggplot2::geom_bar.

Usage

olink_display_plate_dist(data, fill.color = "plate")

olink_displayPlateDistributions(data, fill.color = "plate")

Arguments

data

tibble/data frame in long format returned from the olink_plate_randomizer function.

fill.color

Column name to be used as coloring variable for wells.

Value

An object of class "ggplot" showing the percent distribution of fill.color in each plate (x-axis)

Examples

randomized.manifest <- olink_plate_randomizer(manifest)
olink_display_plate_dist(data=randomized.manifest,
fill.color="Site")

OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.