View source: R/olink_plate_randomizer.R
| olink_display_plate_layout | R Documentation |
Displays each plate in a facet with cells colored by the given variable using ggplot and ggplot2::geom_tile.
olink_display_plate_layout(
data,
fill.color,
PlateSize = 96L,
num_ctrl = 8L,
rand_ctrl = FALSE,
Product,
include.label = FALSE
)
olink_displayPlateLayout(
data,
fill.color,
PlateSize = 96L,
num_ctrl = 8L,
rand_ctrl = FALSE,
Product,
include.label = FALSE
)
data |
tibble/data frame in long format returned from the olink_plate_randomizer function. |
fill.color |
Column name to be used as coloring variable for wells. |
PlateSize |
Integer. Either 96 or 48. 96 is default. |
num_ctrl |
Numeric. Number of controls on each plate (default = 8) |
rand_ctrl |
Logical. Whether controls are added to be randomized across the plate (default = FALSE) |
Product |
String. Name of Olink product used to set PlateSize if not provided. Optional. |
include.label |
Should the variable group be shown in the plot. |
An object of class "ggplot" showing each plate in a facet with the
cells colored by values in column fill.color in input data.
randomized_manifest <- OlinkAnalyze::olink_plate_randomizer(
Manifest = manifest
)
OlinkAnalyze::olink_display_plate_layout(
data = randomized_manifest,
fill.color = "Site"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.