olink_dist_plot: Function to plot the NPX distribution by panel

View source: R/dist_plot.R

olink_dist_plotR Documentation

Description

Generates boxplots of NPX vs. SampleID colored by QC_Warning (default) or any other grouping variable and faceted by Panel using ggplot and ggplot2::geom_boxplot.

Usage

olink_dist_plot(df, check_log = NULL, color_g = "QC_Warning", ...)

Arguments

df

NPX data frame in long format. Must have columns SampleID, NPX and Panel

check_log

Optional named list returned by check_npx(). If NULL, an attached check_log is used when present; otherwise check_npx() will be run internally using df.

color_g

Character value indicating which column to use as fill color. (default: QC_Warning).

...

Color option passed to specify color order.

Value

An object of class "ggplot" which displays NPX distribution for each sample per panel

Examples


cleaned_data <- OlinkAnalyze::clean_npx(
  df = OlinkAnalyze::npx_data1
)

OlinkAnalyze::olink_dist_plot(
  df = OlinkAnalyze::npx_data1,
  color_g = "QC_Warning"
)

OlinkAnalyze::olink_dist_plot(
  df = cleaned_data,
  color_g = "QC_Warning"
)



OlinkAnalyze documentation built on Sept. 18, 2026, 5:06 p.m.