product_to_platesize: Check product name and set plate size accordingly

View source: R/olink_plate_randomizer.R

product_to_platesizeR Documentation

Check product name and set plate size accordingly

Description

If plate size is not provided, function will use accepted_olink_products tibble to map the product name to the plate size

Usage

product_to_platesize(product)

Arguments

product

(String) Name of product (needs to match one of names in accepted_olink_platforms$name)

Value

(Integer) Corresponding plate size per accepted_olink_platforms$plate_size


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.