read_npx_delim: Help function to read long or wide format "Ct", "NPX", or...

View source: R/read_npx_delim.R

read_npx_delimR Documentation

Help function to read long or wide format "Ct", "NPX", or "Quantified" data from delimited "csv" or "txt" files exported from Olink software in R.

Description

The function can handle delimited files in long and wide format.

Usage

read_npx_delim(file, out_df = "arrow")

read_npx_csv(file, out_df = "arrow")

Arguments

file

Path to Olink software output delimited file in wide or long format. Expecting file extensions "csv" or "txt".

out_df

The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble".

Value

Dataset, "tibble" or "ArrowObject", with Olink data in long or wide format.

Author(s)

Klev Diamanti Christoffer Cambronero Kathleen Nevola

See Also

read_npx read_npx_parquet read_npx_zip read_npx_excel read_npx_format


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.