read_npx_delim_long: Help function to read long format "Ct", "NPX", or...

View source: R/read_npx_delim.R

read_npx_delim_longR Documentation

Help function to read long format "Ct", "NPX", or "Quantified" data from delimited "csv" or "txt" files exported from Olink software in R.

Description

The function can handle delimited files in long format.

Usage

read_npx_delim_long(file, sep)

Arguments

file

Path to Olink software output delimited file in wide or long format. Expecting file extensions "csv" or "txt".

sep

Character separator of delimited input file. One of NULL (default) for auto-detection, or ";", ",", " ", "|", and ":". Used only for delimited output files from Olink software.

Value

Dataset, "tibble", with Olink data in long format.

Author(s)

Klev Diamanti Christoffer Cambronero Kathleen Nevola Ola Caster

See Also

read_npx_delim_wide read_npx_delim


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.