read_npx_delim_wide: Help function to read wide format "Ct", "NPX", or...

View source: R/read_npx_delim.R

read_npx_delim_wideR Documentation

Help function to read wide format "Ct", "NPX", or "Quantified" data from delimited "csv" or "txt" files exported from Olink software in R.

Description

The function can handle delimited files in wide format.

Usage

read_npx_delim_wide(file, sep)

Arguments

file

Path to Olink software output delimited file in wide or long format. Expecting file extensions "csv" or "txt".

sep

Character separator of delimited input file. One of NULL (default) for auto-detection, or ";", ",", " ", "|", and ":". Used only for delimited output files from Olink software.

Value

Dataset, "tibble", with Olink data in wide format.

Author(s)

Klev Diamanti

See Also

read_npx_delim_long read_npx_delim


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.