read_npx_excel: Help function to read long or wide format "Ct", "NPX", or...

View source: R/read_npx_excel.R

read_npx_excelR Documentation

Help function to read long or wide format "Ct", "NPX", or "Quantified" data from Microsoft "xls" or "xlsx" files exported from Olink software in R.

Description

Help function to read long or wide format "Ct", "NPX", or "Quantified" data from Microsoft "xls" or "xlsx" files exported from Olink software in R.

Usage

read_npx_excel(file, out_df = "arrow")

Arguments

file

Path to Olink software output excel file in wide or long format. Expected file extensions "xls" or "xlsx".

out_df

The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble".

Value

Dataset, "tibble" or "ArrowObject", with Olink data in long or wide format.

Author(s)

Klev Diamanti Christoffer Cambronero Kathleen Nevola

See Also

read_npx read_npx_parquet read_npx_zip read_npx_format read_npx_delim


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.