read_npx_format_get_platform: Help function to determine the Olink platform from the input...

View source: R/read_npx_format.R

read_npx_format_get_platformR Documentation

Help function to determine the Olink platform from the input dataset.

Description

This function uses the panel name from Olink software files in wide format to determine the qPCR platform that was used for the project that this dataset represents.

Usage

read_npx_format_get_platform(df_top_n, file, olink_platform = NULL)

Arguments

df_top_n

A tibble containing the first read_n rows of the input dataset.

file

Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt".

olink_platform

Olink platform used to generate the input file. One of NULL (default) for auto-detection, "Flex", "Focus", "Target 48", or "Target 96".

Value

The name of the Olink platform. One of "Flex", "Focus", "Target 48", or "Target 96".

Author(s)

Klev Diamanti

See Also

read_npx_format read_npx_format_read read_npx_format_get_format read_npx_format_get_quant


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.