read_npx_format_get_quant: Help function to determine the type of quantification from...

View source: R/read_npx_format.R

read_npx_format_get_quantR Documentation

Help function to determine the type of quantification from the input file in wide format.

Description

This function uses information from the cell A2 from Olink software files in wide format to determine the quantification method of the data that the dataset contains.

Usage

read_npx_format_get_quant(file, data_type = NULL, data_cells)

Arguments

file

Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt".

data_type

Quantification method of the input data. One of "Ct", "NPX", or "Quantified". Defaults to NULL for auto-detection.

data_cells

A character vector with the contents of the cell A2 from the Olink software file in wide format indicating the quantification method.

Value

The name of the data type. One of "Ct", "NPX", or "Quantified".

Author(s)

Klev Diamanti

See Also

read_npx_format read_npx_format_read read_npx_format_get_format read_npx_format_get_platform


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.