read_npx_legacy_check: Help function ensuring 'read_npx_legacy' works

read_npx_legacy_checkR Documentation

Help function ensuring read_npx_legacy works

Description

Help function ensuring read_npx_legacy works

Usage

read_npx_legacy_check(file, df_top, data_type, olink_platform, bottom_mat_v)

Arguments

file

Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt".

df_top

Top matrix of Olink dataset in wide format.

data_type

Quantification method of the input data. One of "Ct", "NPX", or "Quantified". Defaults to NULL for auto-detection.

olink_platform

Olink platform used to generate the input file. One of NULL (default) for auto-detection, "Flex", "Focus", "Target 48", or "Target 96".

bottom_mat_v

Version of the rows in the bottom matrix of the Olink file in wide format based on the local environment variable olink_wide_bottom_matrix.

Value

NULL unless unsupported file is detected.

Author(s)

Klev Diamanti


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.