read_npx_parquet: Help function to read NPX data from long format parquet Olink...

View source: R/read_npx_parquet.R

read_npx_parquetR Documentation

Help function to read NPX data from long format parquet Olink software output file in R.

Description

Help function to read NPX data from long format parquet Olink software output file in R.

Usage

read_npx_parquet(file, out_df = "arrow")

Arguments

file

Path to Olink software output parquet file in long format. Expecting file extension "parquet".

out_df

The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble".

Value

Dataset, "tibble" or "ArrowObject", with Olink data in long format.

Author(s)

Klev Diamanti Kathleen Nevola Pascal Pucholt

See Also

read_npx read_npx_zip read_npx_excel read_npx_format read_npx_delim


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.