read_npx_wide: Convert Olink data in wide format with "Ct", "NPX", and...

View source: R/read_npx_wide.R

read_npx_wideR Documentation

Convert Olink data in wide format with "Ct", "NPX", and "Quantified" data to long format.

Description

Convert Olink data in wide format with "Ct", "NPX", and "Quantified" data to long format.

Usage

read_npx_wide(df, file, data_type, olink_platform)

Arguments

df

A tibble containing the full Olink dataset in wide format.

file

Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt".

data_type

Quantification method of the input data. One of "Ct", "NPX", or "Quantified". Defaults to NULL for auto-detection.

olink_platform

Olink platform used to generate the input file. One of NULL (default) for auto-detection, "Flex", "Focus", "Target 48", or "Target 96".

Value

Dataset, "tibble" or "ArrowObject", with Olink data in long format.

Author(s)

Klev Diamanti

See Also

read_npx_format read_npx_wide_split_row read_npx_wide_npxs_version read_npx_wide_top read_npx_wide_middle read_npx_wide_bottom


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.