read_npx_wide_bottom: Convert the bottom matrix from Olink dataset in wide format...

View source: R/read_npx_wide.R

read_npx_wide_bottomR Documentation

Convert the bottom matrix from Olink dataset in wide format to long.

Description

Use chunks of columns from read_npx_wide_top to covert the bottom matrix df_bottom into a long format tibble.

Usage

read_npx_wide_bottom(
  df,
  file,
  olink_platform,
  data_type,
  col_names,
  format_spec,
  df_plate_panel
)

Arguments

df

Bottom matrix of Olink dataset in wide format df_bottom.

file

Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt".

olink_platform

Olink platform used to generate the input file. One of NULL (default) for auto-detection, "Flex", "Focus", "Target 48", or "Target 96".

data_type

Quantification method of the input data. One of "Ct", "NPX", or "Quantified". Defaults to NULL for auto-detection.

col_names

Names list of character vectors containing column names from each chunk of columns df_top was split on in function. read_npx_wide_top.

format_spec

A tibble derived from olink_wide_spec in the local environment containing the expected format of the Olink wide file based on the olink_platform and data_type.

df_plate_panel

Tibble with unique combinations of panels and plates from the combination of top and middle data frames.

Value

A tibble with the bottom matrix of an Olink wide file in long format.

Author(s)

Klev Diamanti

See Also

read_npx_wide read_npx_wide_split_row read_npx_wide_npxs_version read_npx_wide_top read_npx_wide_middle


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.