read_npx_wide_bottom_version: Additional checks of the bottom matrix of Olink dataset in...

View source: R/read_npx_wide.R

read_npx_wide_bottom_versionR Documentation

Additional checks of the bottom matrix of Olink dataset in wide format.

Description

The rows included in the bottom matrix have evolved through the years. For us to be able to support as many such versions as possible we have used the local environment variable olink_wide_bottom_matrix to mark these different versions. This function extract these version and allows us to check the validity of the data.

Usage

read_npx_wide_bottom_version(df, file, data_type, olink_platform)

Arguments

df

Bottom matrix of Olink dataset in wide format df_bottom.

file

Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt".

data_type

Quantification method of the input data. One of "Ct", "NPX", or "Quantified". Defaults to NULL for auto-detection.

olink_platform

Olink platform used to generate the input file. One of NULL (default) for auto-detection, "Flex", "Focus", "Target 48", or "Target 96".

Value

Tibble with the bottom matrix specifications for the Olink wide file.

Author(s)

Klev Diamanti

See Also

read_npx_wide_bottom


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.