read_npx_wide_check_top: Additional checks of the top matrix of Olink dataset in wide...

View source: R/read_npx_wide.R

read_npx_wide_check_topR Documentation

Additional checks of the top matrix of Olink dataset in wide format.

Description

Additional checks of the top matrix of Olink dataset in wide format.

Usage

read_npx_wide_check_top(df, file, format_spec)

Arguments

df

Top matrix of Olink dataset in wide format df_top.

file

Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt".

format_spec

A tibble derived from olink_wide_spec in the local environment containing the expected format of the Olink wide file based on the olink_platform and data_type.

Value

NULL unless an inconsistency is spotted.

Author(s)

Klev Diamanti

See Also

read_npx_wide_top


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.