read_npx_wide_middle: Split the middle matrix from Olink dataset in wide format.

View source: R/read_npx_wide.R

read_npx_wide_middleR Documentation

Split the middle matrix from Olink dataset in wide format.

Description

Use chunks of columns from read_npx_wide_top to split the middle matrix df_mid into corresponding chunks of columns.

Usage

read_npx_wide_middle(df, file, data_type, col_names)

Arguments

df

Middle matrix of Olink dataset in wide format df_mid.

file

Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt".

data_type

Quantification method of the input data. One of "Ct", "NPX", or "Quantified". Defaults to NULL for auto-detection.

col_names

Names list of character vectors containing column names from each chunk of columns df_top was split on in function. read_npx_wide_top.

Value

A list of data frames (df_oid, df_pid, df_qc_warn and df_int_ctrl) in long format from the middle matrix of an Olink wide file:

  • Data frame containing measurements of Olink assays df_mid_oid

  • Data frame containing plate identifiers df_mid_pid

  • Data frame containing QC warnings df_mid_qc_warn

  • Data frame containing measurements of internal control assays df_mid_int_ctrl

  • Data frame containing measurements of deviations from internal control assays df_mid_dev_int_ctrl

Author(s)

Klev Diamanti

See Also

read_npx_wide read_npx_wide_split_row read_npx_wide_npxs_version read_npx_wide_top read_npx_wide_bottom


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.