read_npx_wide_npxs_version: Extract version of NPX Signature from the head matrix of...

View source: R/read_npx_wide.R

read_npx_wide_npxs_versionR Documentation

Extract version of NPX Signature from the head matrix of Olink datasets in wide format.

Description

Extract version of NPX Signature from the head matrix of Olink datasets in wide format.

Usage

read_npx_wide_npxs_version(df)

Arguments

df

Head matrix of Olink dataset in wide format df_head.

Value

The version of the NPX Signature software.

Author(s)

Klev Diamanti

See Also

read_npx_wide read_npx_wide_split_row read_npx_wide_npxs_version read_npx_wide_top read_npx_wide_middle read_npx_wide_bottom


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.