read_npx_zip: Help function to read "Ct", "NPX", and "Quantified" data from...

View source: R/read_npx_zip.R

read_npx_zipR Documentation

Help function to read "Ct", "NPX", and "Quantified" data from zip-compressed Olink software output files in R.

Description

A zip-compressed input file might contain a file from the Olink software containing "Ct", "NPX", and "Quantified" data, a checksum file and one or more files to be ignored.

Note: The zip-compressed file should strictly contain one Olink data file, none or one checksum file and none or one, or more files that might be ignored.

  • Olink file exported by Olink software in wide or long format. Expecting file extensions "xls", "xlsx", "csv", "txt", and "parquet". This file is subsequently provided as input to read_npx.

  • checksum file One of "MD5_checksum.txt" or "checksum_sha256.txt". depending on the checksum algorithm. The file contains only one line with the checksum string of characters.

  • File(s) to be ignored from the zip file. These files can be named as a character vector in the argument .ignore_files.

Usage

read_npx_zip(
  file,
  out_df = "arrow",
  long_format = NULL,
  olink_platform = NULL,
  data_type = NULL,
  .ignore_files = c("README.txt"),
  quiet = FALSE
)

Arguments

file

Path to Olink software output zip-compressed file in wide or long format. Expected file extensions "zip".

out_df

The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble".

long_format

Boolean marking format of input file. One of TRUE for long format and FALSE for wide format files. Defaults to NULL for auto-detection.

olink_platform

Olink platform used to generate the input file. One of "Target 48", "Flex", "Target 96", "Explore 3072", "Explore HT", "Focus", or "Reveal". Defaults to NULL for auto-detection.

data_type

Quantification method of the input data. One of "Ct", "NPX", or "Quantified". Defaults to NULL for auto-detection.

.ignore_files

Character vector of files included in the zip-compressed Olink software output files that should be ignored. Used only for zip-compressed input files (default = c("README.txt")).

quiet

Boolean to print a confirmation message when reading the input file. Applies to excel or delimited input only. TRUE skips printing the message, and FALSE otherwise.

Value

Dataset, "tibble" or "ArrowObject", with Olink data in long format.

Author(s)

Klev Diamanti Kathleen Nevola Pascal Pucholt

See Also

read_npx read_npx_parquet read_npx_excel read_npx_format read_npx_delim


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.