red_npx_wide_top_mid_long: Combine top and middle matrices in long format.

View source: R/read_npx_wide.R

red_npx_wide_top_mid_longR Documentation

Combine top and middle matrices in long format.

Description

Combined corresponding chunks of columns from the top and middle matrix that were computed from read_npx_wide_top and read_npx_wide_middle, respectively.

Usage

red_npx_wide_top_mid_long(df_top_list, df_middle_list, data_type, format_spec)

Arguments

df_top_list

List of data frames from the top matrix. Output of function read_npx_wide_top.

df_middle_list

List of data frames from the middle matrix. Output of function read_npx_wide_middle.

data_type

Quantification method of the input data. One of "Ct", "NPX", or "Quantified". Defaults to NULL for auto-detection.

format_spec

A tibble derived from olink_wide_spec in the local environment containing the expected format of the Olink wide file based on the olink_platform and data_type.

Value

Tibble in long format combining the top and middle matrices.

Author(s)

Klev Diamanti

See Also

read_npx_wide_top read_npx_wide_middle


OlinkAnalyze documentation built on June 24, 2026, 1:06 a.m.