validate_check_log: Validate a check log list

View source: R/olink_class.R

validate_check_logR Documentation

Validate a check log list

Description

Checks that check_log is a named list with all elements expected by the package internals.

Usage

validate_check_log(df, check_log)

Arguments

df

A tibble or ArrowObject containing Olink NPX data.

check_log

A named list returned by check_npx().

Value

TRUE invisibly if validation passes, otherwise throws an error.


OlinkAnalyze documentation built on Sept. 18, 2026, 5:06 p.m.