View source: R/olink_plate_randomizer.R
| assign_subject2plate | R Documentation |
assign subject to a plate for longitudinal randomization
assign_subject2plate(plate_map, manifest, subject_id)
plate_map |
character vector of locations available for samples including plate, row and columns |
manifest |
sample manifest mapping sample IDs and subject IDs |
subject_id |
id of subject |
plate_map adding sample IDs to plates keeping samples from the same subject on the same plate
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.