| check_checksum | R Documentation |
Runs only if one of "MD5_checksum.txt" or "checksum_sha256.txt". are present in the input zip-compressed file. This function does not check if the checksum_file is in acceptable format.
check_checksum(checksum_file, npx_file)
checksum_file |
Extracted checksum file from the zip-compressed file that contains the checksum file from Olink software. |
npx_file |
Extracted file from the zip-compressed file that contains the Olink data file from Olink software. |
NULL or an error if the files could not be opened or if checksum
did not match.
Klev Diamanti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.