| check_file_exists | R Documentation |
Check one file at a time if it exists.
check_file_exists(file, error = FALSE)
file |
Path to Olink software output file in wide or long format. Expecting extensions "xls" or "xlsx" for excel files, "csv" or "txt" for delim files, "parquet" for parquet files, and "zip" for compressed files. |
error |
Scalar boolean to return an error instead of a |
TRUE if the file exists, and FALSE if not; error if the file does
not exist and error = TRUE.
Klev Diamanti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.