| check_file_extension | R Documentation |
Use variable accepted_npx_file_ext to check if extension of the input file is acceptable. Expecting one of ""xls" or "xlsx" for excel files, "csv" or "txt" for delim files, "parquet" for parquet files, and "zip" for compressed files".
check_file_extension(file)
file |
Path to Olink software output file in wide or long format. Expecting extensions "xls" or "xlsx" for excel files, "csv" or "txt" for delim files, "parquet" for parquet files, and "zip" for compressed files. |
The type of the file extension based on the global variable accepted_npx_file_ext.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.