View source: R/check_library_installed.R
| check_library_installed | R Documentation |
Help function to check if suggested libraries are installed when required.
check_library_installed(x, error = FALSE)
x |
A character vector of R libraries. |
error |
Boolean to return error or a boolean (default). |
Boolean if the library is installed or not, and an error if
error = TRUE.
Klev Diamanti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.