View source: R/check_columns.R
| check_log_colname | R Documentation |
Check if check_log has identified required column in the dataset.
check_log_colname(check_log, col_key)
check_log |
A named list returned by |
col_key |
Column key for which to retrieve alternative column names. One of "sample_id", "sample_type", "assay_type", "olink_id", "uniprot", "assay", "panel", "block", "plate_id", "panel_version", "lod", "quant", "ext_npx", "count", "qc_warning", "assay_warn", "normalization", and "qc_version". |
Nothing or an error message if the required column is missing.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.