| check_npx_all_na_sample | R Documentation |
This function checks if there are samples with the quantified values for all assays NA.
check_npx_all_na_sample(df, col_names)
df |
A "tibble" or "ArrowObject"
from |
col_names |
A list of matched column names. This is the output of the check_npx_col_names function. |
We have added the tags importFrom for "dbplyr" and "duckdb" because "devtools::check()" would complain with a note that the two libraries are imported but never used. To avoid that we used solutions taken from here:
https://github.com/hadley/r-pkgs/issues/203
https://github.com/pbs-software/pbs-modelling/issues/95
A character vector containing SampleID of samples with quantified values NA for all assays, otherwise returns character(0).
Simon Forsberg Masoumeh Sheikhi Klev Diamanti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.