| check_npx_col_class | R Documentation |
This function checks if certain columns from df have the correct type to enable downstream analysis. Columns to be checked are marked as such in the columns col_class and col_class_check of column_name_dict.
check_npx_col_class(df, col_names)
df |
A "tibble" or "ArrowObject"
from |
col_names |
A list of matched column names. This is the output of the check_npx_col_names function. |
A data frame with the columns col_name, col_key, col_class and expected_col_class marking columns with the incorrect type.
Klev Diamanti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.