| check_npx_nonunique_uniprot | R Documentation |
Occasionally, updates in panel versions include updates in UniProt identifiers (e.g. change in formatting). This function identifies cases where an assay identifier OlinkID maps to multiple UniProt identifiers.
check_npx_nonunique_uniprot(df, col_names)
df |
A "tibble" or "ArrowObject"
from |
col_names |
A list of matched column names. This is the output of the check_npx_col_names function. |
A character vector of assay identifiers OlinkID that map to more than one UniProt identifiers.
Kathleen Nevola Kang Dong Klev Diamanti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.