| .check_params | R Documentation |
Common parameters for check functions.
.check_params(x, error)
x |
Variable to check. |
error |
Scalar boolean to return an error instead of a |
Boolean, TRUE or FALSE, if the variable is of the correct class;
If output is FALSE and error = TRUE, an error is thrown.
Klev Diamanti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.