| .check_params | R Documentation |
Common parameters for check functions.
.check_params(x, error)
x |
Variable to check. |
error |
Scalar boolean to return an error instead of a |
Boolean, TRUE or FALSE, if the variable is of the correct class;
If output is FALSE and error = TRUE, an error is thrown.
Klev Diamanti
check_is_character
check_is_integer
check_is_numeric
check_is_boolean
check_is_scalar_character
check_is_scalar_integer
check_is_scalar_numeric
check_is_scalar_boolean
check_is_tibble
check_is_dataset
check_is_arrow_object
check_is_list
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.