| .read_npx_args | R Documentation |
Common parameters for read_npx-related functions.
.read_npx_args(
filename,
file,
out_df,
long_format,
olink_platform,
data_type,
.ignore_files,
quiet,
legacy
)
filename |
Path to Olink software output file in wide or long format. Expecting extensions "xls" or "xlsx" for excel files, "csv" or "txt" for delim files, "parquet" for parquet files, and "zip" for compressed files. |
file |
Path to Olink software output file in wide or long format. Expecting extensions "xls" or "xlsx" for excel files, "csv" or "txt" for delim files, "parquet" for parquet files, and "zip" for compressed files. |
out_df |
The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble". |
long_format |
Boolean marking format of input file. One of |
olink_platform |
Olink platform used to generate the input file. One of
"Target 48", "Flex", "Target 96", "Explore 3072", "Explore HT", "Focus", or "Reveal".
Defaults to |
data_type |
Quantification method of the input data. One of
"Ct", "NPX", or "Quantified". Defaults to
|
.ignore_files |
Character vector of files included in the zip-compressed Olink software output files that should be ignored. Used only for zip-compressed input files (default = c("README.txt")). |
quiet |
Boolean to print a confirmation message when reading the input
file. Applies to excel or delimited input only. |
legacy |
Boolean to run the legacy version of the read_npx function.
Important: should be used only to wide format files from Target 96 or
Target 48 with NPX Software version earlier than 1.8! (default |
Dataset, "tibble" or "ArrowObject", with Olink data in long format.
Klev Diamanti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.