| get_alt_colnames | R Documentation |
Gets alternative column names for a given column key.
get_alt_colnames(col_key)
col_key |
Column key for which to retrieve alternative column names. One of "sample_id", "sample_type", "assay_type", "olink_id", "uniprot", "assay", "panel", "block", "plate_id", "panel_version", "lod", "quant", "ext_npx", "count", "qc_warning", "assay_warn", "normalization", and "qc_version". |
A character vector of alternative column names corresponding to the provided column key.
OlinkAnalyze:::get_alt_colnames(col_key = "sample_id")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.