| get_checksum_file | R Documentation |
Help function to get the file name of the checksum file from the list of contents of a zip-compressed file.
get_checksum_file(files)
files |
A character vector listing file names included in the zip-compressed input file. |
The file name of the checksum file, or NA if file is absent.
Klev Diamanti
read_npx_zip
get_npx_file
check_checksum
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.