View source: R/read_npx_delim.R
| get_field_separator | R Documentation |
This function uses the first line of the provided file to determine the separator of the file.
Note: The function does not allow presence of commas and semicolons on the same line.
get_field_separator(file)
file |
Path to Olink software output delimited file in wide or long format. Expecting file extensions "csv" or "txt". |
The file delimiter ";", ",", " ", "|", or ":".
Klev Diamanti
read_npx_delim
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.