| get_npx_file | R Documentation |
Help function to get the file name of the Olink data file from the list of contents of a zip-compressed file.
get_npx_file(files, excl_file_ext = c("zip"))
files |
A character vector listing file names included in the zip-compressed input file. |
excl_file_ext |
Character vector of file extensions that should not be considered as Olink data file. Mainly used to avoid nested compressed files. |
The file name of the Olink data file.
Klev Diamanti
read_npx_zip
get_checksum_file
check_checksum
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.