View source: R/olink_bridge_selector.R
| olink_bridge_selector | R Documentation |
The bridge selection function will select a number of bridge samples based on the input data. It selects samples with good detection that pass QC and cover a good range of the data. If possible, Olink recommends 8-16 bridge samples. When running the selector, Olink recommends starting at sample_missing_freq = 0.10 which represents a maximum of 10\ per sample. If there are not enough samples output, increase to 20\ The function accepts NPX Excel files with data < LOD replaced.
olink_bridge_selector(df, sample_missing_freq, n, check_log = NULL)
olink_bridgeselector(df, ..., n, check_log = NULL)
df |
Tibble/data frame in long format such as produced by the Olink Analyze read_npx function. |
sample_missing_freq |
The threshold for sample wise missingness. |
n |
Number of bridge samples to be selected. |
check_log |
A named list returned by |
... |
Additional arguments. Currently only accepts |
olink_bridgeselector() is a synonym of olink_bridge_selector() .
A "tibble" with sample IDs and mean NPX for a defined number of bridging samples. Columns include:
SampleID: Sample ID
PercAssaysBelowLOD: Percent of Assays that are below LOD for the sample
MeanNPX: Mean NPX for the sample
check_log <- OlinkAnalyze::check_npx(df = npx_data1)
bridge_samples <- OlinkAnalyze::olink_bridge_selector(
df = npx_data1,
sample_missing_freq = 0.1,
n = 20L,
check_log = check_log
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.