| olink_class | R Documentation |
The olink_class class is a tibble subclass that carries the output of
check_npx() as an attribute. This allows downstream functions to
automatically access the check log without the user having to pass it
explicitly.
For ArrowObjects, check log metadata is stored in the Arrow table's
schema-level metadata under the key "olink_check_log" as a serialized
JSON string.
The class is designed to be fully backward-compatible. All downstream
functions that accept check_log = NULL will first attempt to extract the
check log from the data object itself. If not found, they fall back to the
existing behavior of checking if it was provided by the user through
check_log, and if that is also not found it will run check_npx()
internally.
The olink_class class survives most dplyr operations (e.g.
dplyr::filter(), dplyr::mutate(), dplyr::select()) through the
dplyr::dplyr_reconstruct() mechanism. Note that operations that combine
multiple data frames (e.g. dplyr::bind_rows()) may strip the class and
check log.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.