View source: R/olink_plate_randomizer.R
| olink_display_plate_dist | R Documentation |
Displays a bar chart for each plate representing the distribution of the given grouping variable on each plate using ggplot2::ggplot and ggplot2::geom_bar.
olink_display_plate_dist(data, fill.color = "plate")
olink_displayPlateDistributions(data, fill.color = "plate")
data |
tibble/data frame in long format returned from the olink_plate_randomizer function. |
fill.color |
Column name to be used as coloring variable for wells. |
An object of class "ggplot" showing the percent distribution of fill.color in each plate (x-axis)
randomized.manifest <- olink_plate_randomizer(manifest)
olink_display_plate_dist(data=randomized.manifest,
fill.color="Site")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.