| olink_dist_plot | R Documentation |
Generates boxplots of NPX vs. SampleID colored by QC_Warning (default) or any other grouping variable and faceted by Panel using ggplot and ggplot2::geom_boxplot.
olink_dist_plot(df, check_log = NULL, color_g = "QC_Warning", ...)
df |
NPX data frame in long format. Must have columns SampleID, NPX and Panel |
check_log |
A named list returned by |
color_g |
Character value indicating which column to use as fill color. (default: QC_Warning). |
... |
Color option passed to specify color order. |
An object of class "ggplot" which displays NPX distribution for each sample per panel
# Optional: check and clean dataset
check_log <- OlinkAnalyze::check_npx(
df = npx_data1
)
cleaned_data <- OlinkAnalyze::clean_npx(
df = npx_data1,
check_log = check_log
)
OlinkAnalyze::olink_dist_plot(
df = npx_data1,
check_log = check_log,
color_g = "QC_Warning"
)
OlinkAnalyze::olink_dist_plot(
df = cleaned_data,
check_log = check_log,
color_g = "QC_Warning"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.