View source: R/olink_plate_randomizer.R
| product_to_platesize | R Documentation |
If plate size is not provided, function will use accepted_olink_products tibble to map the product name to the plate size
product_to_platesize(product)
product |
(String) Name of product (needs to match one of names in accepted_olink_platforms$name) |
(Integer) Corresponding plate size per accepted_olink_platforms$plate_size
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.