View source: R/read_npx_delim.R
| read_npx_delim | R Documentation |
The function can handle delimited files in long and wide format.
read_npx_delim(file, out_df = "arrow")
read_npx_csv(file, out_df = "arrow")
file |
Path to Olink software output delimited file in wide or long format. Expecting file extensions "csv" or "txt". |
out_df |
The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble". |
Dataset, "tibble" or "ArrowObject", with Olink data in long or wide format.
Klev Diamanti Christoffer Cambronero Kathleen Nevola
read_npx
read_npx_parquet
read_npx_zip
read_npx_excel
read_npx_format
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.