The function can handle delimited files in long and wide format.
read_npx_delim(file, out_df = "arrow")read_npx_csv(file, out_df = "arrow")
Dataset, "tibble" or "ArrowObject", with Olink data in long or wide format.
Path to Olink software output delimited file in wide or long format. Expecting file extensions "csv" or "txt".
The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble".
Klev Diamanti Christoffer Cambronero Kathleen Nevola
read_npx
read_npx_parquet
read_npx_zip
read_npx_excel
read_npx_format