View source: R/read_npx_delim.R
| read_npx_delim_long | R Documentation |
The function can handle delimited files in long format.
read_npx_delim_long(file, sep)
file |
Path to Olink software output delimited file in wide or long format. Expecting file extensions "csv" or "txt". |
sep |
Character separator of delimited input file. One of |
Dataset, "tibble", with Olink data in long format.
Klev Diamanti Christoffer Cambronero Kathleen Nevola Ola Caster
read_npx_delim_wide
read_npx_delim
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.