View source: R/read_npx_excel.R
| read_npx_excel | R Documentation |
Help function to read long or wide format "Ct", "NPX", or "Quantified" data from Microsoft "xls" or "xlsx" files exported from Olink software in R.
read_npx_excel(file, out_df = "arrow")
file |
Path to Olink software output excel file in wide or long format. Expected file extensions "xls" or "xlsx". |
out_df |
The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble". |
Dataset, "tibble" or "ArrowObject", with Olink data in long or wide format.
Klev Diamanti Christoffer Cambronero Kathleen Nevola
read_npx
read_npx_parquet
read_npx_zip
read_npx_format
read_npx_delim
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.