View source: R/read_npx_format.R
| read_npx_format | R Documentation |
This function processes Olink software excel or delimited files regardless of data type, platform or format.
Olink software excel files with the extension
"xls" or "xlsx"
are imported in R by the function read_npx_excel.
Olink software delimited files with suffix
"csv" or "txt"
are imported in R by the functions read_npx_delim or
read_npx_csv.
Files in wide format are subsequently handled by the function
read_npx_wide.
Olink software files in wide format always originate from Olink qPCR
platforms, and are further processed by the functions
read_npx_format_get_platform and
read_npx_format_get_quant to determine the data type and Olink
platform, respectively.
read_npx_format(
file,
out_df = "arrow",
long_format = NULL,
olink_platform = NULL,
data_type = NULL,
quiet = FALSE,
legacy = FALSE
)
file |
Path to Olink software output file in wide or long format. Expecting file extensions "xls", "xlsx", "csv", or "txt". |
out_df |
The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble". |
long_format |
Boolean marking format of input file. One of |
olink_platform |
Olink platform used to generate the input file. One of
"Target 48", "Flex", "Target 96", "Explore 3072", "Explore HT", "Focus", or "Reveal".
Defaults to |
data_type |
Quantification method of the input data. One of
"Ct", "NPX", or "Quantified". Defaults to
|
quiet |
Boolean to print a confirmation message when reading the input
file. Applies to excel or delimited input only. |
legacy |
Boolean to enforce returning a list containing
olink_platform, data_type and long_format information together with the
dataset. Used only when |
Dataset, "tibble" or "ArrowObject", with Olink data in long format.
Klev Diamanti Kathleen Nevola Pascal Pucholt Christoffer Cambronero Boxi Zhang Olof Mansson Marianne Sandin
read_npx
read_npx_format_read
read_npx_format_get_format
read_npx_format_get_platform
read_npx_format_get_quant
read_npx_legacy
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.