View source: R/read_npx_format.R
| read_npx_format_get_platform | R Documentation |
This function uses the panel name from Olink software files in wide format to determine the qPCR platform that was used for the project that this dataset represents.
read_npx_format_get_platform(df_top_n, file, olink_platform = NULL)
df_top_n |
A tibble containing the first read_n rows of the input dataset. |
file |
Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt". |
olink_platform |
Olink platform used to generate the input file.
One of |
The name of the Olink platform. One of "Flex", "Focus", "Target 48", or "Target 96".
Klev Diamanti
read_npx_format
read_npx_format_read
read_npx_format_get_format
read_npx_format_get_quant
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.