View source: R/read_npx_format.R
| read_npx_format_get_quant | R Documentation |
This function uses information from the cell A2 from Olink software files in wide format to determine the quantification method of the data that the dataset contains.
read_npx_format_get_quant(file, data_type = NULL, data_cells)
file |
Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt". |
data_type |
Quantification method of the input data. One of
"Ct", "NPX", or "Quantified". Defaults to
|
data_cells |
A character vector with the contents of the cell A2 from the Olink software file in wide format indicating the quantification method. |
The name of the data type. One of "Ct", "NPX", or "Quantified".
Klev Diamanti
read_npx_format
read_npx_format_read
read_npx_format_get_format
read_npx_format_get_platform
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.