View source: R/read_npx_format.R
| read_npx_format_read | R Documentation |
This function reads Olink software excel and delimited files regardless of data type, platform or format.
Olink software excel files with the extension
"xls" or "xlsx"
are imported in R by the function read_npx_excel.
Olink software delimited files with suffix
"csv" or "txt"
are imported in R by the functions read_npx_delim or
read_npx_csv.
Files in long format are read with the column row as column names.
Files in wide format are read with column names as V1, V2, etc.
This function also extracts the first read_n rows of the dataset to determine the Olink platform that generated the file, the data type and and file format.
read_npx_format_read(file, read_n = 3L)
file |
Path to Olink software output file in wide or long format. Expecting file extensions "xls", "xlsx", "csv", or "txt". |
read_n |
Number of top n rows to read. |
A list with two elements:
An ArrowObject (df) containing the full dataset in wide or long format.
A tibble (df_top_n) containing the read_n rows of the full dataset. This subset of data is used to determine long_format, olink_platform and data_type.
Klev Diamanti
read_npx_format
read_npx_format_get_format
read_npx_format_get_platform
read_npx_format_get_quant
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.