| read_npx_legacy | R Documentation |
This implementation of read_NPX does not cover the latest
versions of Olink files in wide format. Specifically, it supports:
Target 96 output files in wide format (T96 reports only NPX) with the bottom matrix containing one of the following combinations of rows:
Missing Data freq. and LOD. # nolint: line_length_linter
Missing Data freq., LOD, and Normalization. # nolint: line_length_linter
Target 48 output files in wide format NPX with the bottom matrix containing the following rows: Missing Data freq., Normalization, and LOD. # nolint: line_length_linter
Target 48 output files in wide format absolute Quantification with the bottom matrix containing the following rows: Assay warning, LLOQ, Lowest quantifiable level, Missing Data freq., Normalization, Plate_LOD, and ULOQ. # nolint: line_length_linter
This function would accept data exported in wide format from Olink NPX Signature 1.7.1 or earlier, or NPX Manager.
read_npx_legacy(
file,
out_df = "tibble",
olink_platform = NULL,
data_type = NULL,
quiet = TRUE
)
file |
Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt". |
out_df |
The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble". |
olink_platform |
Olink platform used to generate the input file.
One of |
data_type |
Quantification method of the input data. One of
"Ct", "NPX", or "Quantified". Defaults to
|
quiet |
Boolean to print a confirmation message when reading the input
file. Applies to excel or delimited input only. |
Dataset, "tibble" or "ArrowObject", with Olink data in long format.
Klev Diamanti Kathleen Nevola Pascal Pucholt Christoffer Cambronero Boxi Zhang Olof Mansson Marianne Sandin
read_npx_format_read
read_npx_format_get_format
read_npx_format_get_platform
read_npx_format_get_quant
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.