| read_npx_legacy_check | R Documentation |
read_npx_legacy worksHelp function ensuring read_npx_legacy works
read_npx_legacy_check(file, df_top, data_type, olink_platform, bottom_mat_v)
file |
Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt". |
df_top |
Top matrix of Olink dataset in wide format. |
data_type |
Quantification method of the input data. One of
"Ct", "NPX", or "Quantified". Defaults to
|
olink_platform |
Olink platform used to generate the input file.
One of |
bottom_mat_v |
Version of the rows in the bottom matrix of the Olink file in wide format based on the local environment variable olink_wide_bottom_matrix. |
NULL unless unsupported file is detected.
Klev Diamanti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.