View source: R/read_npx_legacy.R
| read_npx_legacy_help | R Documentation |
read_npx_format and
read_npx_wide to streamline read_npx_legacyHelp function utilizing functions from read_npx_format and
read_npx_wide to streamline read_npx_legacy
read_npx_legacy_help(
file,
out_df,
olink_platform = NULL,
data_type = NULL,
data_type_no_accept = c("Ct")
)
file |
Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt". |
out_df |
The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble". |
olink_platform |
Olink platform used to generate the input file.
One of |
data_type |
Quantification method of the input data. One of
"Ct", "NPX", or "Quantified". Defaults to
|
data_type_no_accept |
Character vector of data types that should be rejected (default = "Ct"). |
A list of objects containing the following:
olink_platform: auto-detected Olink platform. One of "Flex", "Focus", "Target 48", and "Target 96".
long_format: auto-detected Olink format. Should always be "FALSE".
data_type: auto-detected Olink data type. One of "NPX" and "Quantified". # nolint: line_length_linter
df_split: list of 2 tibbles. Top matrix from the Olink wide file, and middle combined with bottom matrix.
npxs_v: Olink NPX software version.
bottom_mat_v: bottom matrix version based on olink_wide_bottom_matrix.
format_spec: specifications of the wide format based on olink_wide_spec.
Klev Diamanti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.