View source: R/read_npx_parquet.R
| read_npx_parquet | R Documentation |
Help function to read NPX data from long format parquet Olink software output file in R.
read_npx_parquet(file, out_df = "arrow")
file |
Path to Olink software output parquet file in long format. Expecting file extension "parquet". |
out_df |
The class of the output dataset. One of "tibble" or "arrow". Defaults to "tibble". |
Dataset, "tibble" or "ArrowObject", with Olink data in long format.
Klev Diamanti Kathleen Nevola Pascal Pucholt
read_npx
read_npx_zip
read_npx_excel
read_npx_format
read_npx_delim
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.