View source: R/read_npx_wide.R
| read_npx_wide | R Documentation |
Convert Olink data in wide format with "Ct", "NPX", and "Quantified" data to long format.
read_npx_wide(df, file, data_type, olink_platform)
df |
A tibble containing the full Olink dataset in wide format. |
file |
Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt". |
data_type |
Quantification method of the input data. One of
"Ct", "NPX", or "Quantified". Defaults to
|
olink_platform |
Olink platform used to generate the input file.
One of |
Dataset, "tibble" or "ArrowObject", with Olink data in long format.
Klev Diamanti
read_npx_format
read_npx_wide_split_row
read_npx_wide_npxs_version
read_npx_wide_top
read_npx_wide_middle
read_npx_wide_bottom
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.