View source: R/read_npx_wide.R
| read_npx_wide_bottom | R Documentation |
Use chunks of columns from read_npx_wide_top to covert the
bottom matrix df_bottom into a long format tibble.
read_npx_wide_bottom(
df,
file,
olink_platform,
data_type,
col_names,
format_spec,
df_plate_panel
)
df |
Bottom matrix of Olink dataset in wide format df_bottom. |
file |
Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt". |
olink_platform |
Olink platform used to generate the input file.
One of |
data_type |
Quantification method of the input data. One of
"Ct", "NPX", or "Quantified". Defaults to
|
col_names |
Names list of character vectors containing column names from
each chunk of columns df_top was split on in function.
|
format_spec |
A tibble derived from olink_wide_spec in the local environment containing the expected format of the Olink wide file based on the olink_platform and data_type. |
df_plate_panel |
Tibble with unique combinations of panels and plates from the combination of top and middle data frames. |
A tibble with the bottom matrix of an Olink wide file in long format.
Klev Diamanti
read_npx_wide
read_npx_wide_split_row
read_npx_wide_npxs_version
read_npx_wide_top
read_npx_wide_middle
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.