View source: R/read_npx_wide.R
| read_npx_wide_bottom_version | R Documentation |
The rows included in the bottom matrix have evolved through the years. For us to be able to support as many such versions as possible we have used the local environment variable olink_wide_bottom_matrix to mark these different versions. This function extract these version and allows us to check the validity of the data.
read_npx_wide_bottom_version(df, file, data_type, olink_platform)
df |
Bottom matrix of Olink dataset in wide format df_bottom. |
file |
Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt". |
data_type |
Quantification method of the input data. One of
"Ct", "NPX", or "Quantified". Defaults to
|
olink_platform |
Olink platform used to generate the input file.
One of |
Tibble with the bottom matrix specifications for the Olink wide file.
Klev Diamanti
read_npx_wide_bottom
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.