View source: R/read_npx_wide.R
| read_npx_wide_check_top | R Documentation |
Additional checks of the top matrix of Olink dataset in wide format.
read_npx_wide_check_top(df, file, format_spec)
df |
Top matrix of Olink dataset in wide format df_top. |
file |
Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt". |
format_spec |
A tibble derived from olink_wide_spec in the local environment containing the expected format of the Olink wide file based on the olink_platform and data_type. |
NULL unless an inconsistency is spotted.
Klev Diamanti
read_npx_wide_top
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.