View source: R/read_npx_wide.R
| read_npx_wide_middle | R Documentation |
Use chunks of columns from read_npx_wide_top to split the
middle matrix df_mid into corresponding chunks of columns.
read_npx_wide_middle(df, file, data_type, col_names)
df |
Middle matrix of Olink dataset in wide format df_mid. |
file |
Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt". |
data_type |
Quantification method of the input data. One of
"Ct", "NPX", or "Quantified". Defaults to
|
col_names |
Names list of character vectors containing column names from
each chunk of columns df_top was split on in function.
|
A list of data frames (df_oid, df_pid, df_qc_warn and df_int_ctrl) in long format from the middle matrix of an Olink wide file:
Data frame containing measurements of Olink assays df_mid_oid
Data frame containing plate identifiers df_mid_pid
Data frame containing QC warnings df_mid_qc_warn
Data frame containing measurements of internal control assays df_mid_int_ctrl
Data frame containing measurements of deviations from internal control assays df_mid_dev_int_ctrl
Klev Diamanti
read_npx_wide
read_npx_wide_split_row
read_npx_wide_npxs_version
read_npx_wide_top
read_npx_wide_bottom
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.