View source: R/read_npx_wide.R
| read_npx_wide_npxs_version | R Documentation |
Extract version of NPX Signature from the head matrix of Olink datasets in wide format.
read_npx_wide_npxs_version(df)
df |
Head matrix of Olink dataset in wide format df_head. |
The version of the NPX Signature software.
Klev Diamanti
read_npx_wide
read_npx_wide_split_row
read_npx_wide_npxs_version
read_npx_wide_top
read_npx_wide_middle
read_npx_wide_bottom
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.