View source: R/read_npx_wide.R
| read_npx_wide_top | R Documentation |
The function splits the top matrix df_top into chunks of columns, each of which contains separate information that will be combined with matching chunks from df_mid to convert the wide dataset into a long one.
read_npx_wide_top(df, file, olink_platform, format_spec)
df |
Top matrix of Olink dataset in wide format df_top. |
file |
Path to Olink software output file in wide format. Expected one of file extensions "xls", "xlsx", "csv", or "txt". |
olink_platform |
Olink platform used to generate the input file.
One of |
format_spec |
A tibble derived from olink_wide_spec in the local environment containing the expected format of the Olink wide file based on the olink_platform and data_type. |
A list of data frames from top matrix in long format:
Data frame containing Olink assays df_top_oid
Data frame containing plate identifiers df_top_pid
Data frame containing QC warnings df_top_qc_warn
Data frame containing internal control assays df_top_int_ctrl
Data frame containing deviation from internal control assays df_top_dev_int_ctrl
Klev Diamanti
read_npx_wide
read_npx_wide_split_row
read_npx_wide_npxs_version
read_npx_wide_middle
read_npx_wide_bottom
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.