View source: R/read_npx_wide.R
| red_npx_wide_top_mid_long | R Documentation |
Combined corresponding chunks of columns from the top and middle matrix
that were computed from read_npx_wide_top and
read_npx_wide_middle, respectively.
red_npx_wide_top_mid_long(df_top_list, df_middle_list, data_type, format_spec)
df_top_list |
List of data frames from the top matrix. Output of
function |
df_middle_list |
List of data frames from the middle matrix. Output of
function |
data_type |
Quantification method of the input data. One of
"Ct", "NPX", or "Quantified". Defaults to
|
format_spec |
A tibble derived from olink_wide_spec in the local environment containing the expected format of the Olink wide file based on the olink_platform and data_type. |
Tibble in long format combining the top and middle matrices.
Klev Diamanti
read_npx_wide_top
read_npx_wide_middle
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.