| run_check_npx | R Documentation |
check_npx() if not provided.Check and run check_npx() if not provided.
run_check_npx(df, check_log = NULL)
df |
A "tibble" or "ArrowObject"
from |
check_log |
A named list returned by |
This function acts as a wrapper for check_npx(). It will check if the
input check_log provided by the user is valid. If not, it will throw
relevant errors or warnings. Alternatively, if check_log was not provided
by the user, it will run check_npx() to provide check_log to enable
downstream functions to run.#'
A list containing the following elements:
col_names List of column names from the input data frame marking the columns to be used in downstream analyses.
oid_invalid Character vector of invalid OlinkID.
assay_na Character vector of assays with all samples having NA values.
sample_id_dups Character vector of duplicate SampleID.
sample_id_na Character vector containing SampleID of samples with quantified values NA for all assays.
col_class Data frame with columns of incorrect type including column key col_key, column name col_name, detected column type col_class and expected column type expected_col_class.
assay_qc Character vector containing OlinkID of assays with at least one assay warning.
non_unique_uniprot Character vector of OlinkID mapped to more than one UniProt ID.
darid_invalid Character vector containing outdated combinations of DataAnalysisRefID and PanelDataArchiveVersion.
Klev Diamanti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.