| validate_check_log | R Documentation |
Checks that check_log is a named list with all elements expected by
the package internals.
validate_check_log(df, check_log)
df |
A tibble or ArrowObject containing Olink NPX data. |
check_log |
A named list returned by |
TRUE invisibly if validation passes, otherwise throws an error.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.